#include "ParamRange.h"
#include "Utils.h"

namespace ffgl
{

ParamRange::ParamRange( const std::string& name, float defaultValue, const RangeStruct range ) :
	ParamRange( name, ParameterType::FF_TYPE_STANDARD, name, defaultValue, range )
{
}

ParamRange::ParamRange( const std::string& name, const std::string& uniformName, float defaultValue, const RangeStruct range ) :
	ParamRange( name, ParameterType::FF_TYPE_STANDARD, uniformName, defaultValue, range )
{
}

ParamRange::ParamRange( const std::string& name, ParameterType type, float defaultValue, const RangeStruct range ) :
	ParamRange( name, type, name, defaultValue, range )
{
}

ParamRange::ParamRange( const std::string& name, ParameterType type, const std::string& uniformName, float defaultValue, const RangeStruct range ) :
	ParamFloat( name, type, uniformName, utils::map( defaultValue, range.min, range.max, 0.0f, 1.0f ) ),
	range( range )
{
}

ParamRange::~ParamRange()
{
}

//const std::string& ParamRange::GetDisplay() const
//{
//	static std::string displayString;
//	displayString = std::to_string( GetRealValue() );
//	return displayString;
//}

const RangeStruct ParamRange::GetRange() const
{
	return range;
}

void ParamRange::SetRange( const RangeStruct newRange )
{
	range = newRange;
}

float ParamRange::GetFloatValue() const
{
	// Scale the raw value to the specified range
	return utils::map( ParamFloat::GetFloatValue(), 0.0, 1.0, range.min, range.max );
}

}//End namespace ffgl